{******************************************************************}
{                                                                  }
{ Borland Delphi APi for Windows Media Format 7.1                  }
{    Date  : 16-09-2001                                            }
{    Autor : Henri GOURVEST                                        }
{    Email : hgourvest@progdigy.com                                }
{    home  : http://www.progdigy.com                               }
{                                                                  }
{ Contributor: Thomas Schimming                                    }
{                                                                  }
{ The contents of this file are used with permission, subject to   }
{ the Mozilla Public License Version 1.1 (the "License"); you may  }
{ not use this file except in compliance with the License. You may }
{ obtain a copy of the License at                                  }
{ http://www.mozilla.org/MPL/MPL-1.1.html                          }
{                                                                  }
{ Software distributed under the License is distributed on an      }
{ "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or   }
{ implied. See the License for the specific language governing     }
{ rights and limitations under the License.                        }
{                                                                  }
{******************************************************************}

unit WMFUtil;

interface

uses
  Windows, Classes, ComObj, ActiveX, WMF, DirectShow;

const
  IID_IServiceProvider : TGUID = '{6d5140c1-7436-11ce-8034-00aa006009fa}';
  IID_IUnknown         : TGUID = '{00000000-0000-0000-C000-000000000046}';
  IID_IObjectWithSite  : TGUID = '{FC4801A3-2BA9-11CF-A229-00AA003D7352}';

type
  TWMKeyProvider = class(TInterfacedObject,IServiceProvider)
  private
    m_cRef: ULONG;
  public
    constructor Create;
    function QueryService(const rsid, iid: TGuid; out Obj): HResult; stdcall;
  end;

  TWMPofiles = (
    wmp_Unknown,
    wmp_V40_DialUpMBR,
    wmp_V40_IntranetMBR,
    wmp_V40_2856100MBR,
    wmp_V40_6VoiceAudio,
    wmp_V40_16AMRadio,
    wmp_V40_288FMRadioMono,
    wmp_V40_288FMRadioStereo,
    wmp_V40_56DialUpStereo,
    wmp_V40_64Audio,
    wmp_V40_96Audio,
    wmp_V40_128Audio,
    wmp_V40_288VideoVoice,
    wmp_V40_288VideoAudio,
    wmp_V40_288VideoWebServer,
    wmp_V40_56DialUpVideo,
    wmp_V40_56DialUpVideoWebServer,
    wmp_V40_100Video,
    wmp_V40_250Video,
    wmp_V40_512Video,
    wmp_V40_1MBVideo,
    wmp_V40_3MBVideo,
    wmp_V70_DialUpMBR,
    wmp_V70_IntranetMBR,
    wmp_V70_2856100MBR,
    wmp_V70_288VideoVoice,
    wmp_V70_288VideoAudio,
    wmp_V70_288VideoWebServer,
    wmp_V70_56VideoWebServer,
    wmp_V70_64VideoISDN,
    wmp_V70_100Video,
    wmp_V70_256Video,
    wmp_V70_384Video,
    wmp_V70_768Video,
    wmp_V70_1500Video,
    wmp_V70_2000Video,
    wmp_V70_700FilmContentVideo,
    wmp_V70_1500FilmContentVideo,
    wmp_V70_6VoiceAudio,
    wmp_V70_288FMRadioMono,
    wmp_V70_288FMRadioStereo,
    wmp_V70_56DialUpStereo,
    wmp_V70_64AudioISDN,
    wmp_V70_64Audio,
    wmp_V70_96Audio,
    wmp_V70_128Audio
  );

function WMCertificateAdd(pGraph: IFilterGraph; out KeyProvider : TWMKeyProvider): HRESULT; stdcall;
function WMCertificateRemove(pGraph: IFilterGraph; KeyProvider : TWMKeyProvider): HRESULT; stdcall;

function GuidToProfile(GUID: TGUID): TWMPofiles;
function ProfileToGuid(Profile: TWMPofiles): TGUID;

type
  EASFError = EOleSysError;

  TWMProfileManager = class(TComponent, IWMProfileManager2)
  private
    FWMProfileManager: IWMProfileManager2;
    FCustomProfileText: TStrings;
    function GetCustomProfile: IWMProfile;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    property WMProfileManager: IWMProfileManager2 read FWMProfileManager implements IWMProfileManager2;
    property CustomProfile: IWMProfile read GetCustomProfile;
  published
    property CustomProfileText: TStrings read FCustomProfileText write FCustomProfileText;
  end;

procedure ASFError(ErrorCode: HResult);
procedure ASFCheck(Result: HResult);

resourcestring
  S_ASF_E_BUFFEROVERRUN              = 'An attempt was made to seek or position past the end of a buffer.';
  S_ASF_E_BUFFERTOOSMALL             = 'The supplied input or output buffer was too small.';
  S_ASF_E_BADLANGUAGEID              = 'The language ID was not found.';
  S_ASF_E_NOPAYLOADLENGTH            = 'The multiple payload packet is missing the payload length.';
  S_ASF_E_TOOMANYPAYLOADS            = 'The packet contains too many payloads.';
  S_ASF_E_PACKETCONTENTTOOLARGE      = 'ASF_E_PACKETCONTENTTOOLAR';
  S_ASF_E_UNKNOWNPACKETSIZE          = 'Expecting a fixed packet size but min. and max. are not equal.';
  S_ASF_E_INVALIDHEADER              = 'ASF_E_INVALIDHEAD';
  S_ASF_E_NOCLOCKOBJECT              = 'The object does not have a valid clock object.';
  S_ASF_E_UNKNOWNCLOCKTYPE           = 'ASF_E_UNKNOWNCLOCKTY';
  S_ASF_E_OPAQUEPACKET               = 'An attempt was made to restore or access an opaque packet.';
  S_ASF_E_WRONGVERSION               = 'ASF_E_WRONGVERSI';
  S_ASF_E_OVERFLOW                   = 'An attempt was made to store a value which was larger than then destination''s maximum value.';
  S_ASF_E_NOTFOUND                   = 'The object was not found.';
  S_ASF_E_OBJECTTOOBIG               = 'The object is too large to be processed in the requested manner.';
  S_ASF_E_UNEXPECTEDVALUE            = 'A value was not set as expected.';
  S_ASF_E_INVALIDSTATE               = 'The request is not valid in the object''s current state.';
  S_ASF_E_NOLIBRARY                  = 'This object does not have a valid library pointer; it was not properly created or it has been Shutdown().';
  S_ASF_E_ALREADYINITIALIZED         = 'This object has already been initialized; the setting cannot be changed.';
  S_ASF_E_INVALIDINIT                = 'This object has not been initialized properly; that operation cannot be performed.';
  S_ASF_E_NOHEADEROBJECT             = 'The ASF Header object could not be found.';
  S_ASF_E_NODATAOBJECT               = 'The ASF Data object could not be found.';
  S_ASF_E_NOINDEXOBJECT              = 'The ASF Index object could not be found.';
  S_ASF_E_NOSTREAMPROPS              = 'A Stream Properties object with the correct stream number could not be found.';
  S_ASF_E_NOFILEPROPS                = 'The File Properties object could not be found.';
  S_ASF_E_NOLANGUAGELIST             = 'The Language List object could not be found.';
  S_ASF_E_NOINDEXPARAMETERS          = 'The Index Parameters object could not be found.';
  S_ASF_E_UNSUPPORTEDERRORCONCEALMENT = 'The requested error concealment strategy is not supported by this component.';
  S_ASF_E_INVALIDFLAGS               = 'The flags for this object or set of objects are not properly set.';
  S_ASF_E_BADDATADESCRIPTOR          = 'One or more data descriptors is not properly set.';
  S_ASF_E_BADINDEXTIMEINTERVAL       = 'The index has an invalid time interval (probably zero).';
  S_ASF_E_INVALIDTIME                = 'The given time value is not valid.';
  S_ASF_E_INVALIDINDEX               = 'The given index value is not valid.';
  S_ASF_E_STREAMNUMBERINUSE          = 'The specified stream number is already in use.';
  S_ASF_E_BADMEDIATYPE               = 'The specified media type does not work with this component.';
  S_ASF_E_WRITEFAILED                = 'The object could not be written as specified.';
  S_ASF_E_NOTENOUGHDESCRIPTORS       = 'The given data unit requires a larger number of descriptors to be fully parsed.';
  S_ASF_E_INDEXBLOCKUNLOADED         = 'The index entries for the specified index block have been unloaded from memory and are not available.';
  S_ASF_E_NOTENOUGHBANDWIDTH         = 'The specified bandwidth is not large enough.';
  S_ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE  = 'The object has exceeded its maximum size.';
  S_ASF_E_BADDATAUNIT                = 'The given data unit is corrupted, badly formatted, or otherwise not valid.';
  S_ASF_E_HEADERSIZE                 = 'The ASF header has exceeded the specified maximum size.';
  S_ASF_S_OPAQUEPACKET               = 'ASF_S_OPAQUEPACK';

procedure Register;

implementation

{ Register Components }

procedure Register;
begin
//  RegisterComponents('Windows Media', [TWMProfileManager]);
end;

constructor TWMKeyProvider.Create;
begin
  m_cRef := 0;
end;

function TWMKeyProvider.QueryService(const rsid, iid: TGuid; out Obj): HResult;
var
  punkCert : IUnknown;
  hr       : HRESULT;
begin
  if(IsEqualGUID(rsid,IID_IWMReader) and IsEqualGUID(iid,IID_IUnknown)) then
  begin
    hr := WMCreateCertificate(punkCert);
    if(SUCCEEDED(hr)) then IUnknown(obj) := punkCert;
    result := hr;
  end
  else
    result := E_NOINTERFACE;
end;

function WMCertificateAdd(pGraph: IFilterGraph; out KeyProvider : TWMKeyProvider): HRESULT; stdcall;
var
  pObjectWithSite: IObjectWithSite;
  hr: HRESULT;
begin
  result := E_FAIL;
  if(pGraph<>nil) then
  begin
    // need to disconnect the filter graph's site
    hr := pGraph.QueryInterface(IID_IObjectWithSite, pObjectWithSite);
    if(SUCCEEDED(hr)) then
    begin
      KeyProvider := TWMKeyProvider.create;
      KeyProvider._AddRef();
      result := pObjectWithSite.SetSite(IServiceProvider(KeyProvider));
      pObjectWithSite := nil;
    end;
  end
  else
    result := E_INVALIDARG;
end;

function WMCertificateRemove(pGraph: IFilterGraph; KeyProvider : TWMKeyProvider): HRESULT; stdcall;
var
  pObjectWithSite: IObjectWithSite;
  hr: HRESULT;
begin
  result := E_FAIL;
  if(pGraph<>nil) then
  begin
    hr := pGraph.QueryInterface(IID_IObjectWithSite, pObjectWithSite);
    if(SUCCEEDED(hr)) then
    begin
      result := pObjectWithSite.SetSite(nil);
      pObjectWithSite := nil;
    end;
  end
  else
    result := E_INVALIDARG;
  if Assigned(KeyProvider) then
  begin
    KeyProvider._Release;
  end;
end;

{ Raise EASFError exception from an error code }

procedure ASFError(ErrorCode: HResult);
//var
 // ErrBuf: array[0..255] of Char;
begin
  case ErrorCode of
    HResult(ASF_E_BUFFEROVERRUN)               : EASFError.Create(PChar(S_ASF_E_BUFFEROVERRUN),ErrorCode,0);
    HResult(ASF_E_BUFFERTOOSMALL)              : EASFError.Create(PChar(S_ASF_E_BUFFERTOOSMALL),ErrorCode,0);
    HResult(ASF_E_BADLANGUAGEID)               : EASFError.Create(PChar(S_ASF_E_BADLANGUAGEID),ErrorCode,0);
    HResult(ASF_E_NOPAYLOADLENGTH)             : EASFError.Create(PChar(S_ASF_E_NOPAYLOADLENGTH),ErrorCode,0);
    HResult(ASF_E_TOOMANYPAYLOADS)             : EASFError.Create(PChar(S_ASF_E_TOOMANYPAYLOADS),ErrorCode,0);
    HResult(ASF_E_PACKETCONTENTTOOLARGE)       : EASFError.Create(PChar(S_ASF_E_PACKETCONTENTTOOLARGE),ErrorCode,0);
    HResult(ASF_E_UNKNOWNPACKETSIZE)           : EASFError.Create(PChar(S_ASF_E_UNKNOWNPACKETSIZE),ErrorCode,0);
    HResult(ASF_E_INVALIDHEADER)               : EASFError.Create(PChar(S_ASF_E_INVALIDHEADER),ErrorCode,0);
    HResult(ASF_E_NOCLOCKOBJECT)               : EASFError.Create(PChar(S_ASF_E_NOCLOCKOBJECT),ErrorCode,0);
    HResult(ASF_E_UNKNOWNCLOCKTYPE)            : EASFError.Create(PChar(S_ASF_E_UNKNOWNCLOCKTYPE),ErrorCode,0);
    HResult(ASF_E_OPAQUEPACKET)                : EASFError.Create(PChar(S_ASF_E_OPAQUEPACKET),ErrorCode,0);
    HResult(ASF_E_WRONGVERSION)                : EASFError.Create(PChar(S_ASF_E_WRONGVERSION),ErrorCode,0);
    HResult(ASF_E_OVERFLOW)                    : EASFError.Create(PChar(S_ASF_E_OVERFLOW),ErrorCode,0);
    HResult(ASF_E_NOTFOUND)                    : EASFError.Create(PChar(S_ASF_E_NOTFOUND),ErrorCode,0);
    HResult(ASF_E_OBJECTTOOBIG)                : EASFError.Create(PChar(S_ASF_E_OBJECTTOOBIG),ErrorCode,0);
    HResult(ASF_E_UNEXPECTEDVALUE)             : EASFError.Create(PChar(S_ASF_E_UNEXPECTEDVALUE),ErrorCode,0);
    HResult(ASF_E_INVALIDSTATE)                : EASFError.Create(PChar(S_ASF_E_INVALIDSTATE),ErrorCode,0);
    HResult(ASF_E_NOLIBRARY)                   : EASFError.Create(PChar(S_ASF_E_NOLIBRARY),ErrorCode,0);
    HResult(ASF_E_ALREADYINITIALIZED)          : EASFError.Create(PChar(S_ASF_E_ALREADYINITIALIZED),ErrorCode,0);
    HResult(ASF_E_INVALIDINIT)                 : EASFError.Create(PChar(S_ASF_E_INVALIDINIT),ErrorCode,0);
    HResult(ASF_E_NOHEADEROBJECT)              : EASFError.Create(PChar(S_ASF_E_NOHEADEROBJECT),ErrorCode,0);
    HResult(ASF_E_NODATAOBJECT)                : EASFError.Create(PChar(S_ASF_E_NODATAOBJECT),ErrorCode,0);
    HResult(ASF_E_NOINDEXOBJECT)               : EASFError.Create(PChar(S_ASF_E_NOINDEXOBJECT),ErrorCode,0);
    HResult(ASF_E_NOSTREAMPROPS)               : EASFError.Create(PChar(S_ASF_E_NOSTREAMPROPS),ErrorCode,0);
    HResult(ASF_E_NOFILEPROPS)                 : EASFError.Create(PChar(S_ASF_E_NOFILEPROPS),ErrorCode,0);
    HResult(ASF_E_NOLANGUAGELIST)              : EASFError.Create(PChar(S_ASF_E_NOLANGUAGELIST),ErrorCode,0);
    HResult(ASF_E_NOINDEXPARAMETERS)           : EASFError.Create(PChar(S_ASF_E_NOINDEXPARAMETERS),ErrorCode,0);
    HResult(ASF_E_UNSUPPORTEDERRORCONCEALMENT) : EASFError.Create(PChar(S_ASF_E_UNSUPPORTEDERRORCONCEALMENT),ErrorCode,0);
    HResult(ASF_E_INVALIDFLAGS)                : EASFError.Create(PChar(S_ASF_E_INVALIDFLAGS),ErrorCode,0);
    HResult(ASF_E_BADDATADESCRIPTOR)           : EASFError.Create(PChar(S_ASF_E_BADDATADESCRIPTOR),ErrorCode,0);
    HResult(ASF_E_BADINDEXTIMEINTERVAL)        : EASFError.Create(PChar(S_ASF_E_BADINDEXTIMEINTERVAL),ErrorCode,0);
    HResult(ASF_E_INVALIDTIME)                 : EASFError.Create(PChar(S_ASF_E_INVALIDTIME),ErrorCode,0);
    HResult(ASF_E_INVALIDINDEX)                : EASFError.Create(PChar(S_ASF_E_INVALIDINDEX),ErrorCode,0);
    HResult(ASF_E_STREAMNUMBERINUSE)           : EASFError.Create(PChar(S_ASF_E_STREAMNUMBERINUSE),ErrorCode,0);
    HResult(ASF_E_BADMEDIATYPE)                : EASFError.Create(PChar(S_ASF_E_BADMEDIATYPE),ErrorCode,0);
    HResult(ASF_E_WRITEFAILED)                 : EASFError.Create(PChar(S_ASF_E_WRITEFAILED),ErrorCode,0);
    HResult(ASF_E_NOTENOUGHDESCRIPTORS)        : EASFError.Create(PChar(S_ASF_E_NOTENOUGHDESCRIPTORS),ErrorCode,0);
    HResult(ASF_E_INDEXBLOCKUNLOADED)          : EASFError.Create(PChar(S_ASF_E_INDEXBLOCKUNLOADED),ErrorCode,0);
    HResult(ASF_E_NOTENOUGHBANDWIDTH)          : EASFError.Create(PChar(S_ASF_E_NOTENOUGHBANDWIDTH),ErrorCode,0);
    HResult(ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE)   : EASFError.Create(PChar(S_ASF_E_EXCEEDEDMAXIMUMOBJECTSIZE),ErrorCode,0);
    HResult(ASF_E_BADDATAUNIT)                 : EASFError.Create(PChar(S_ASF_E_BADDATAUNIT),ErrorCode,0);
    HResult(ASF_E_HEADERSIZE)                  : EASFError.Create(PChar(S_ASF_E_HEADERSIZE),ErrorCode,0);
    HResult(ASF_S_OPAQUEPACKET)                : EASFError.Create(PChar(S_ASF_S_OPAQUEPACKET),ErrorCode,0);
    else raise EASFError.Create('', ErrorCode, 0);
  end;
end;

{ Raise EASFError exception if result code indicates an error }

procedure ASFCheck(Result: HResult);
begin
  if not Succeeded(Result) then ASFError(Result);
end;

{ TWMProfileManager }

constructor TWMProfileManager.Create(AOwner: TComponent);
var
  PM: IWMProfileManager;
begin
  inherited;
  FCustomProfileText := TStringList.Create;
  if not (csDesigning in ComponentState) then
  begin
    ASFCheck(WMCreateProfileManager(PM));
    FWMProfileManager := PM as IWMProfileManager2;
    FWMProfileManager.SetSystemProfileVersion(WMT_VER_7_0);
  end;
end;

destructor TWMProfileManager.Destroy;
begin
  FWMProfileManager := nil;
  FCustomProfileText.Free;
  inherited;
end;

function TWMProfileManager.GetCustomProfile: IWMProfile;
var
  ProfileStr: WideString;
begin
  ProfileStr := FCustomProfileText.Text;
  ASFCheck(FWMProfileManager.LoadProfileByData(PWideChar(ProfileStr),Result));
end;

function GuidToProfile(GUID: TGUID): TWMPofiles;
begin
  if IsEqualGUID(GUID, WMProfile_V40_DialUpMBR)              then result := wmp_V40_DialUpMBR else
  if IsEqualGUID(GUID, WMProfile_V40_IntranetMBR)            then result := wmp_V40_IntranetMBR else
  if IsEqualGUID(GUID, WMProfile_V40_2856100MBR)             then result := wmp_V40_2856100MBR else
  if IsEqualGUID(GUID, WMProfile_V40_6VoiceAudio)            then result := wmp_V40_6VoiceAudio else
  if IsEqualGUID(GUID, WMProfile_V40_16AMRadio)              then result := wmp_V40_16AMRadio else
  if IsEqualGUID(GUID, WMProfile_V40_288FMRadioMono)         then result := wmp_V40_288FMRadioMono else
  if IsEqualGUID(GUID, WMProfile_V40_288FMRadioStereo)       then result := wmp_V40_288FMRadioStereo else
  if IsEqualGUID(GUID, WMProfile_V40_56DialUpStereo)         then result := wmp_V40_56DialUpStereo else
  if IsEqualGUID(GUID, WMProfile_V40_64Audio)                then result := wmp_V40_64Audio else
  if IsEqualGUID(GUID, WMProfile_V40_96Audio)                then result := wmp_V40_96Audio else
  if IsEqualGUID(GUID, WMProfile_V40_128Audio)               then result := wmp_V40_128Audio else
  if IsEqualGUID(GUID, WMProfile_V40_288VideoVoice)          then result := wmp_V40_288VideoVoice else
  if IsEqualGUID(GUID, WMProfile_V40_288VideoAudio)          then result := wmp_V40_288VideoAudio else
  if IsEqualGUID(GUID, WMProfile_V40_288VideoWebServer)      then result := wmp_V40_288VideoWebServer else
  if IsEqualGUID(GUID, WMProfile_V40_56DialUpVideo)          then result := wmp_V40_56DialUpVideo else
  if IsEqualGUID(GUID, WMProfile_V40_56DialUpVideoWebServer) then result := wmp_V40_56DialUpVideoWebServer else
  if IsEqualGUID(GUID, WMProfile_V40_100Video)               then result := wmp_V40_100Video else
  if IsEqualGUID(GUID, WMProfile_V40_250Video)               then result := wmp_V40_250Video else
  if IsEqualGUID(GUID, WMProfile_V40_512Video)               then result := wmp_V40_512Video else
  if IsEqualGUID(GUID, WMProfile_V40_1MBVideo)               then result := wmp_V40_1MBVideo else
  if IsEqualGUID(GUID, WMProfile_V40_3MBVideo)               then result := wmp_V40_3MBVideo else
  if IsEqualGUID(GUID, WMProfile_V70_DialUpMBR)              then result := wmp_V70_DialUpMBR else
  if IsEqualGUID(GUID, WMProfile_V70_IntranetMBR)            then result := wmp_V70_IntranetMBR else
  if IsEqualGUID(GUID, WMProfile_V70_2856100MBR)             then result := wmp_V70_2856100MBR else
  if IsEqualGUID(GUID, WMProfile_V70_288VideoVoice)          then result := wmp_V70_288VideoVoice else
  if IsEqualGUID(GUID, WMProfile_V70_288VideoAudio)          then result := wmp_V70_288VideoAudio else
  if IsEqualGUID(GUID, WMProfile_V70_288VideoWebServer)      then result := wmp_V70_288VideoWebServer else
  if IsEqualGUID(GUID, WMProfile_V70_56VideoWebServer)       then result := wmp_V70_56VideoWebServer else
  if IsEqualGUID(GUID, WMProfile_V70_64VideoISDN)            then result := wmp_V70_64VideoISDN else
  if IsEqualGUID(GUID, WMProfile_V70_100Video)               then result := wmp_V70_100Video else
  if IsEqualGUID(GUID, WMProfile_V70_256Video)               then result := wmp_V70_256Video else
  if IsEqualGUID(GUID, WMProfile_V70_384Video)               then result := wmp_V70_384Video else
  if IsEqualGUID(GUID, WMProfile_V70_768Video)               then result := wmp_V70_768Video else
  if IsEqualGUID(GUID, WMProfile_V70_1500Video)              then result := wmp_V70_1500Video else
  if IsEqualGUID(GUID, WMProfile_V70_2000Video)              then result := wmp_V70_2000Video else
  if IsEqualGUID(GUID, WMProfile_V70_700FilmContentVideo)    then result := wmp_V70_700FilmContentVideo else
  if IsEqualGUID(GUID, WMProfile_V70_1500FilmContentVideo)   then result := wmp_V70_1500FilmContentVideo else
  if IsEqualGUID(GUID, WMProfile_V70_6VoiceAudio)            then result := wmp_V70_6VoiceAudio else
  if IsEqualGUID(GUID, WMProfile_V70_288FMRadioMono)         then result := wmp_V70_288FMRadioMono else
  if IsEqualGUID(GUID, WMProfile_V70_288FMRadioStereo)       then result := wmp_V70_288FMRadioStereo else
  if IsEqualGUID(GUID, WMProfile_V70_56DialUpStereo)         then result := wmp_V70_56DialUpStereo else
  if IsEqualGUID(GUID, WMProfile_V70_64AudioISDN)            then result := wmp_V70_64AudioISDN else
  if IsEqualGUID(GUID, WMProfile_V70_64Audio)                then result := wmp_V70_64Audio else
  if IsEqualGUID(GUID, WMProfile_V70_96Audio)                then result := wmp_V70_96Audio else
  if IsEqualGUID(GUID, WMProfile_V70_128Audio)               then result := wmp_V70_128Audio else
  result := wmp_Unknown;
end;

function ProfileToGUID(Profile: TWMPofiles): TGUID;
begin
  case profile of
    wmp_Unknown                    : result := GUID_NULL;
    wmp_V40_DialUpMBR              : result := WMProfile_V40_DialUpMBR;
    wmp_V40_IntranetMBR            : result := WMProfile_V40_IntranetMBR;
    wmp_V40_2856100MBR             : result := WMProfile_V40_2856100MBR;
    wmp_V40_6VoiceAudio            : result := WMProfile_V40_6VoiceAudio;
    wmp_V40_16AMRadio              : result := WMProfile_V40_16AMRadio;
    wmp_V40_288FMRadioMono         : result := WMProfile_V40_288FMRadioMono;
    wmp_V40_288FMRadioStereo       : result := WMProfile_V40_288FMRadioStereo;
    wmp_V40_56DialUpStereo         : result := WMProfile_V40_56DialUpStereo;
    wmp_V40_64Audio                : result := WMProfile_V40_64Audio;
    wmp_V40_96Audio                : result := WMProfile_V40_96Audio;
    wmp_V40_128Audio               : result := WMProfile_V40_128Audio;
    wmp_V40_288VideoVoice          : result := WMProfile_V40_288VideoVoice;
    wmp_V40_288VideoAudio          : result := WMProfile_V40_288VideoAudio;
    wmp_V40_288VideoWebServer      : result := WMProfile_V40_288VideoWebServer;
    wmp_V40_56DialUpVideo          : result := WMProfile_V40_56DialUpVideo;
    wmp_V40_56DialUpVideoWebServer : result := WMProfile_V40_56DialUpVideoWebServer;
    wmp_V40_100Video               : result := WMProfile_V40_100Video;
    wmp_V40_250Video               : result := WMProfile_V40_250Video;
    wmp_V40_512Video               : result := WMProfile_V40_512Video;
    wmp_V40_1MBVideo               : result := WMProfile_V40_1MBVideo;
    wmp_V40_3MBVideo               : result := WMProfile_V40_3MBVideo;
    wmp_V70_DialUpMBR              : result := WMProfile_V70_DialUpMBR;
    wmp_V70_IntranetMBR            : result := WMProfile_V70_IntranetMBR;
    wmp_V70_2856100MBR             : result := WMProfile_V70_2856100MBR;
    wmp_V70_288VideoVoice          : result := WMProfile_V70_288VideoVoice;
    wmp_V70_288VideoAudio          : result := WMProfile_V70_288VideoAudio;
    wmp_V70_288VideoWebServer      : result := WMProfile_V70_288VideoWebServer;
    wmp_V70_56VideoWebServer       : result := WMProfile_V70_56VideoWebServer;
    wmp_V70_64VideoISDN            : result := WMProfile_V70_64VideoISDN;
    wmp_V70_100Video               : result := WMProfile_V70_100Video;
    wmp_V70_256Video               : result := WMProfile_V70_256Video;
    wmp_V70_384Video               : result := WMProfile_V70_384Video;
    wmp_V70_768Video               : result := WMProfile_V70_768Video;
    wmp_V70_1500Video              : result := WMProfile_V70_1500Video;
    wmp_V70_2000Video              : result := WMProfile_V70_2000Video;
    wmp_V70_700FilmContentVideo    : result := WMProfile_V70_700FilmContentVideo;
    wmp_V70_1500FilmContentVideo   : result := WMProfile_V70_1500FilmContentVideo;
    wmp_V70_6VoiceAudio            : result := WMProfile_V70_6VoiceAudio;
    wmp_V70_288FMRadioMono         : result := WMProfile_V70_288FMRadioMono;
    wmp_V70_288FMRadioStereo       : result := WMProfile_V70_288FMRadioStereo;
    wmp_V70_56DialUpStereo         : result := WMProfile_V70_56DialUpStereo;
    wmp_V70_64AudioISDN            : result := WMProfile_V70_64AudioISDN;
    wmp_V70_64Audio                : result := WMProfile_V70_64Audio;
    wmp_V70_96Audio                : result := WMProfile_V70_96Audio;
    wmp_V70_128Audio               : result := WMProfile_V70_128Audio;
  else
    result := GUID_NULL;
  end;
end;


end.
